.. pydss documentation master file, created by
   sphinx-quickstart on Wed Sep  6 19:53:31 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Unbalanced grid builder
=======================

.. image::  png/logo_name.png
	:width: 400px
	:align: center



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   definitions
   formulation.ipynb
   elements



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
